<?php
class booksmanager extends cmsFrontend {

    protected $useOptions = true;
    public $storage;

    public function __construct(cmsRequest $request){
        parent::__construct($request);
        $config = cmsConfig::getInstance();
        $this->storage = PATH.$config->upload_root.'books/';
    }

    public function createBook($book_item, $user){
        $bookname = md5($book_item['id']);
        $book_id = $this->model->insert('booksmanager', array(
            'item_id' => $book_item['id'],
            'title' => $book_item['title'],
            'name' => $bookname,
            'path' => $this->createBookFolder($bookname),
            'author' => $user->nickname,
            'author_id' => $user->id,
            'version' => '1.0'
        ));
        return $this->getBook($book_id);
    }

    public function createBookFolder($name){
        $config = cmsConfig::getInstance();
        $dirname = $this->storage.$name;
        if(!is_dir($dirname)) mkdir($dirname);
        return $config->upload_root.'books/'.$name;
    }

    public function getBookFolder($name){
        return $this->storage.$name;
    }

    public function allowThisBook($user, $book){
		if(!$user->is_logged) return false; 
        if($user->is_admin) return true;
        if($user->id == $book['user']['id']) return true;
        return false;
    }

    public function calcBookSymbols($book){
        if(count($book['chapters']) == 0) return 0;
        $count = 0;
        foreach($book['chapters'] as $chapter) $count += $chapter['symbols'];
        return$count;
    }

    public function getBook($book_id){
        $book = $this->model->filterEqual('id', $book_id)->getItem('booksmanager');
        if($book) $book['chapters'] = cmsModel::yamlToArray($book['chapters']);
        return $book;
    }

    public function getBookByParent($parent_id){
        $book = $this->model->filterEqual('item_id', $parent_id)->getItem('booksmanager');
        if($book) $book['chapters'] = cmsModel::yamlToArray($book['chapters']);
        return $book;
    }

    public function getChaptersList($book_id){
        return $this->model->filterEqual('id', $book_id)->getFieldFiltered('booksmanager', 'chapters');
    }

    public function getChaptersHtml($book){
        if(empty($book['chapters'])) return '<div class="book-btn add-first-chapter" rel="add" onclick="addChapter(); return false;">Добавить первую главу</div>';
        $html = '<div class="book-btn" rel="add" onclick="addChapter(); return false;">Добавить главу</div><div class="selected-delete book-btn">Удалить отмеченные</div><div class="book-chapters">';

        foreach ($book['chapters'] as $chapter){
            $chapter_id = str_replace('.txt', '', $chapter['filename']);
            $html .= '<div id="'.$chapter_id.'" class="book-chapter">';
            $html .= '<input id="del-flag" type="checkbox" name="chapter_id[]" value="'.$chapter_id.'">';
            $html .= '<h3 onclick="viewChapter(\''.$chapter_id.'\');"><span class="title">'.$chapter['title'].'</span><span class="chapter-count"> ('.html_spellcount($chapter['symbols'], 'знак', 'знака', 'знаков').')</span></h3>';
            $html .= '<div class="chapter-details">'.date('d.m.Y H:m', strtotime($chapter['date_pub'])).($chapter['date_pub'] != $chapter['last_modified'] ? ' (изменена '.date('d.m.Y H:m', strtotime($chapter['last_modified'])).')' : '').' <span class="chapter-edit" onclick="editChapter(\''.$chapter_id.'\');">Редактировать</span></div>';
            $html .= '</div>';
        }
        $html .= '</div>';
        return $html;
    }

    public function getChaptersListHtml($book){
        $html = '';
        $html = '<div class="book-chapters in-item">';
        foreach ($book['chapters'] as $chapter){
            $chapter_id = str_replace('.txt', '', $chapter['filename']);
            $html .= '<div id="'.$chapter_id.'" class="book-chapter">';
            $html .= '<h3 onclick="viewChapter(\''.$chapter_id.'\');"><span class="title">'.$chapter['title'].'</span></h3>';
            $html .= '<div class="chapter-details">'.date('d.m.Y H:m', strtotime($chapter['date_pub'])).($chapter['date_pub'] != $chapter['last_modified'] ? ' (изменена '.date('d.m.Y H:m', strtotime($chapter['last_modified'])).')' : '').'</div>';
            $html .= '</div>';
        }
        $html .= '</div>';
        return $html;
    }

    public function addChapter($bookname, $filename, $content){
        $folder = $this->storage.$bookname;
        if(!file_exists($folder)) mkdir($folder, 0777);
        $filename = $this->storage.$bookname.'/'.$filename.'.txt';
        file_put_contents($filename, $content);
        return is_readable($filename);
    }

    public function getChapterContent($bookname, $filename){
        return file_get_contents($this->storage.$bookname.'/'.$filename.'.txt');
    }

    public function deleteChapter($bookname, $filename){
        unlink($this->storage.$bookname.'/'.$filename.'.txt');
    }

}
